noahtheduke.fluent


add-resourceclj/s

(add-resource bundle resource)

Creates a copy of the given bundle and adds the provided string resource to it.

Creates a copy of the given bundle and adds the provided string resource to it.
sourceraw docstring

buildclj/s

(build locale-str resource)

Create a new FluentBundle for the given locale with the provided resource.

Create a new FluentBundle for the given locale with the provided resource.
sourceraw docstring

formatclj/s

(format bundle id)
(format bundle id args)

Find message for id, format it with any args, return it.

Find message for id, format it with any args, return it.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries