noahtheduke.fluent.pprint


FTLPrintercljprotocol

-pprintclj

(-pprint this ctx)
source

indentclj

(indent ctx)
source

pprintclj

(pprint resource)

Format and print a Fluent object to out.

Format and print a Fluent object to *out*.
sourceraw docstring

pprint-strclj

(pprint-str resource)

Format and print a Fluent object to a string.

Format and print a Fluent object to a string.
sourceraw docstring

writeclj

(write ctx s)
source

cljdoc builds & hosts documentation for Clojure/Script libraries