(add-resource bundle resource)Creates a copy of the given bundle and adds the provided string resource to it.
Creates a copy of the given bundle and adds the provided string resource to it.
(build locale-str resource)Create a new FluentBundle for the given locale with the provided resource.
Create a new FluentBundle for the given locale with the provided resource.
(format bundle id)(format bundle id args)Find message for id, format it with any args, return it.
Find message for id, format it with any args, return it.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |