(pprint resource)Format and print a Fluent object to out.
Format and print a Fluent object to *out*.
(pprint-str resource)Format and print a Fluent object to a string.
Format and print a Fluent object to a string.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |